@@ -32,7 +32,10 @@ renv_bootstrap_repos <- function() {
   repos <- getOption("repos")
 
   # ensure @CRAN@ entries are resolved
-  repos[repos == "@CRAN@"] <- "https://cloud.r-project.org"
+  repos[repos == "@CRAN@"] <- getOption(
+    "renv.repos.cran",
+    "https://cloud.r-project.org"
+  )
 
   # add in renv.bootstrap.repos if set
   default <- c(FALLBACK = "https://cloud.r-project.org")
@@ -96,77 +99,75 @@ renv_bootstrap_download_impl <- function(url, destfile) {
 
 renv_bootstrap_download_cran_latest <- function(version) {
 
-  repos <- renv_bootstrap_download_cran_latest_find(version)
+  spec <- renv_bootstrap_download_cran_latest_find(version)
 
   message("* Downloading renv ", version, " ... ", appendLF = FALSE)
 
-  downloader <- function(type) {
+  type  <- spec$type
+  repos <- spec$repos
 
-    tryCatch(
-      utils::download.packages(
-        pkgs = "renv",
-        destdir = tempdir(),
-        repos = repos,
-        type = type,
-        quiet = TRUE
-      ),
-      condition = identity
-    )
+  info <- tryCatch(
+    utils::download.packages(
+      pkgs    = "renv",
+      destdir = tempdir(),
+      repos   = repos,
+      type    = type,
+      quiet   = TRUE
+    ),
+    condition = identity
+  )
 
-  }
-
-  # first, try downloading a binary on Windows + macOS if appropriate
-  binary <-
-    !identical(.Platform$pkgType, "source") &&
-    !identical(getOption("pkgType"), "source") &&
-    Sys.info()[["sysname"]] %in% c("Darwin", "Windows")
-
-  if (binary) {
-    info <- downloader(type = "binary")
-    if (!inherits(info, "condition")) {
-      message("OK (downloaded binary)")
-      return(info[1, 2])
-    }
-  }
-
-  # otherwise, try downloading a source tarball
-  info <- downloader(type = "source")
   if (inherits(info, "condition")) {
     message("FAILED")
     return(FALSE)
   }
 
   # report success and return
-  message("OK (downloaded source)")
+  message("OK (downloaded ", type, ")")
   info[1, 2]
 
 }
 
 renv_bootstrap_download_cran_latest_find <- function(version) {
 
-  all <- renv_bootstrap_repos()
+  # check whether binaries are supported on this system
+  binary <-
+    getOption("renv.bootstrap.binary", default = TRUE) &&
+    !identical(.Platform$pkgType, "source") &&
+    !identical(getOption("pkgType"), "source") &&
+    Sys.info()[["sysname"]] %in% c("Darwin", "Windows")
 
-  for (repos in all) {
+  types <- c(if (binary) "binary", "source")
 
-    db <- tryCatch(
-      as.data.frame(
-        x = utils::available.packages(repos = repos),
-        stringsAsFactors = FALSE
-      ),
-      error = identity
-    )
+  # iterate over types + repositories
+  for (type in types) {
+    for (repos in renv_bootstrap_repos()) {
 
-    if (inherits(db, "error"))
-      next
+      # retrieve package database
+      db <- tryCatch(
+        as.data.frame(
+          utils::available.packages(type = type, repos = repos),
+          stringsAsFactors = FALSE
+        ),
+        error = identity
+      )
 
-    entry <- db[db$Package %in% "renv" & db$Version %in% version, ]
-    if (nrow(entry) == 0)
-      next
+      if (inherits(db, "error"))
+        next
 
-    return(repos)
+      # check for compatible entry
+      entry <- db[db$Package %in% "renv" & db$Version %in% version, ]
+      if (nrow(entry) == 0)
+        next
 
+      # found it; return spec to caller
+      spec <- list(entry = entry, type = type, repos = repos)
+      return(spec)
+
+    }
   }
 
+  # if we got here, we failed to find renv
   fmt <- "renv %s is not available from your declared package repositories"
   stop(sprintf(fmt, version))
 
