@@ -2,9 +2,15 @@
 #' Hydrate a Project
 #'
 #' Discover the \R packages used within a project, and then install those
-#' packages into the active library. This effectively allows you to clone the
+#' packages into the active library. This effectively allows you to fork the
 #' state of your default \R libraries for use within a project library.
 #'
+#' It may occasionally be useful to use `renv::hydrate()` to update the packages
+#' used within a project that has already been initialized. However, be warned
+#' that it's possible that the packages pulled in may not actually be compatible
+#' with the packages installed in the project library, so you should exercise
+#' caution when doing so.
+#'
 #' @section Sources:
 #'
 #' `hydrate()` attempts to re-use packages already installed on your system,
@@ -34,6 +40,11 @@
 #' @param library The \R library to be hydrated. When `NULL`, the active
 #'   library as reported by `.libPaths()` is used.
 #'
+#' @param update Boolean; should `hydrate()` attempt to update already-installed
+#'   packages if the requested package is already installed in the project
+#'   library? Set this to `"all"` if you'd like _all_ packages to be refreshed
+#'   from the source library if possible.
+#'
 #' @param sources A set of library paths from which `renv` should attempt to
 #'   draw packages. See **Sources** for more details.
 #'
@@ -52,6 +63,7 @@
 hydrate <- function(packages = NULL,
                     ...,
                     library = NULL,
+                    update  = FALSE,
                     sources = NULL,
                     project = NULL)
 {
@@ -78,12 +90,12 @@ hydrate <- function(packages = NULL,
   # get and construct path to library
   ensure_directory(library)
 
-  # copy packages from user library to cache
-  linkable <-
-    renv_cache_config_enabled(project = project) &&
-    renv_cache_config_symlinks(project = project) &&
-    renv_path_same(library, renv_paths_library(project = project))
+  # only hydrate with packages that are either not currently installed,
+  # or (if update = TRUE) the version in the library is newer
+  packages <- renv_hydrate_filter(packages, library, update)
 
+  # copy packages from user library to cache
+  linkable <- renv_cache_linkable(project = project, library = library)
   if (linkable)
     renv_hydrate_link_packages(packages, library)
   else
@@ -97,6 +109,57 @@ hydrate <- function(packages = NULL,
   invisible(result)
 }
 
+renv_hydrate_filter <- function(packages, library, update) {
+
+  # run filter
+  keep <- enumerate(
+    packages,
+    renv_hydrate_filter_impl,
+    library = library,
+    update = update,
+    FUN.VALUE = logical(1)
+  )
+
+  # filter based on kept packages
+  packages[keep]
+
+}
+
+renv_hydrate_filter_impl <- function(package, path, library, update) {
+
+  # if user has requested hydration of all packages, respect that
+  if (identical(update, "all"))
+    return(TRUE)
+
+  # is the package already installed in the requested library?
+  # if not, then we'll want to hydrate this package
+  # if so, we'll want to compare the version first and
+  # hydrate only if the requested version is newer than the current
+  descpath <- file.path(library, package, "DESCRIPTION")
+  desc <- catch(renv_description_read(path = descpath))
+  if (inherits(desc, "error"))
+    return(TRUE)
+
+  # get the current package version
+  current <- catch(numeric_version(desc[["Version"]]))
+  if (inherits(current, "error"))
+    return(TRUE)
+
+  # if the package is already installed and we're not updating, stop here
+  if (identical(update, FALSE))
+    return(FALSE)
+
+  # check to-be-copied package version
+  requested <- catch({
+    desc <- renv_description_read(path = path)
+    numeric_version(desc[["Version"]])
+  })
+
+  # only hydrate with a newer version
+  requested > current
+
+}
+
 renv_hydrate_packages <- function(project, libpaths = NULL) {
 
   deps <- dependencies(project, quiet = TRUE, dev = TRUE)
